# Corning Inc.

Corning Incorporated is an American manufacturer of glass, ceramics, and related materials, primarily for industrial and scientific applications. Among other products, Corning has developed and is manufacruring the Gorilla glass: a specialized toughened alkali-aluminosilicate glass used in the displays of most of the modern smartphones.

## External links

- Corning | Materials Science Technology and Innovation
- Corning Inc. - Wikipedia
- Corning Museum of Glass
- Gorilla Glass - Wikipedia